@@ -42,8 +42,6 @@ def 帮助():
     help_mod = input()
     if help_mod == "1":
 
-
-
         print(
             f"logs.分割线('这是logs模块的', 'Fishconsole{fcv.version()}帮助文档'\n)"
             "你是不是不知道怎么用的？那就让我来告诉你吧!!\n"
@@ -57,24 +55,39 @@ def 帮助():
             f"{logs.颜色('粉色', 色选='粉色')}，{logs.颜色('红色', 色选='红色')}，{logs.颜色('黄色', 色选='黄色')}，{logs.颜色('蓝色', 色选='蓝色')}，{logs.颜色('火粉', 色选='火粉')}，{logs.颜色('紫色', 色选='紫色')}，{logs.颜色('淡黄', 色选='淡黄')}\n"
             f' {logs.颜色("测试", 色选="淡蓝背")}{logs.颜色("测试", 色选="紫背")}{logs.颜色("测试", 色选="绿背")}{logs.颜色("测试", 色选="蓝背")}{logs.颜色("测试", 色选="黄背")}{logs.颜色("测试", 色选="红背")}\n'
             " (注意哦,分割线和日志都是可以和颜色叠加使用的)\n"
+            "‘input输入加强’，原版的input支持输出提示文字，但是默认为空且不好识别，我就针对这种情况对它进行重写了一次，这一次，辨识度绝对高/dogedoge/手臂\n"
             "---------------------\n"
             "‘分割线’的语法是:\n"
-            "logs.分割线(标题,文本,颜色选择)\n"
+            "logs.分割线(标题,文本,颜色选择)\n\n"
             "‘日志’的语法是:\n"
-            "logs.日志(显示文字,颜色选择)\n"
+            "logs.日志(显示文字,颜色选择)\n\n"
             "‘颜色’的语法是:\n"
-            "logs.颜色(输出显示文字,颜色选择)\n"
-            "---------------------\n"
+            "logs.颜色(输出显示文字,颜色选择)\n\n"
+            "‘input输入加强’的语法是:\n"
+            "logs.输入(输出显示文字,颜色选择)\n\n"
+            "ps.推荐一个写法（全局参数），语法是"
+            "全局参数='红色'\n"
+            "a = 输入('a', 全局参数)\n"
+            "a = 输入('a', 全局参数)\n"
+            "a = 输入('a', 全局参数)\n"
+            "全局参数='蓝色'\n"
+            "a = 输入('a', 全局参数)\n"
+            "a = 输入('a', 全局参数)\n"
+            "a = 输入('a', 全局参数)\n"
+            "这种写法极快的提升了编写的效率，也达到了Fishconsole logs模块的初衷（我们拒绝让一个庞大的工程变得难以调试）\n"
+
+            "---------------------"
         )
         exit()
     else:
-        res = window.列表选择对话框("关于控制台输出模块的帮助文档会显示在命令行中，选中你想查看的内容，我们将会提供相应的窗口。为什么有的地方找不到",f"Fishconsole {fcv.version()} 帮助文档",
+        res = window.列表选择对话框("关于控制台输出模块的帮助文档会显示在命令行中，选中你想查看的内容，我们将会提供相应的窗口。为什么有的地方找不到",
+                             f"Fishconsole {fcv.version()} 帮助文档",
                              ["Matplotlib中文辅助模块", "easygui中文辅助模块", "logs控制台输出辅助模块", "tool玩具模块"])
 
         if res is not None:
             for a in res:
                 if a == "logs控制台输出辅助模块":
-                    print(logs.分割线("这是logs模块的", f"Fishconsole{fcv.version()} 帮助文档","红色"))
+                    print(logs.分割线("这是logs模块的", f"Fishconsole{fcv.version()} 帮助文档", "红色"))
                     print(
                         "你是不是不知道怎么用的？那就让我来告诉你吧!!\n"
                         "这个函数是一个输出工具的集合，是由鱼鱼有几斤整理的\n"
@@ -86,7 +99,8 @@ def 帮助():
                         "3：‘颜色’，更改输出的颜色，目前支持的有：\n"
                         f"{logs.颜色('粉色', 色选='粉色')}，{logs.颜色('红色', 色选='红色')}，{logs.颜色('黄色', 色选='黄色')}，{logs.颜色('蓝色', 色选='蓝色')}，{logs.颜色('火粉', 色选='火粉')}，{logs.颜色('紫色', 色选='紫色')}，{logs.颜色('淡黄', 色选='淡黄')}\n"
                         f' {logs.颜色("测试", 色选="淡蓝背")}{logs.颜色("测试", 色选="紫背")}{logs.颜色("测试", 色选="绿背")}{logs.颜色("测试", 色选="蓝背")}{logs.颜色("测试", 色选="黄背")}{logs.颜色("测试", 色选="红背")}\n'
-                        " (注意哦,分割线和日志都是可以和颜色叠加使用的)\n"
+                        " (注意哦,分割线和日志都是可以和颜色叠加使用的)\n\n"
+                        "4:‘input输入加强’，原版的input支持输出提示文字，但是默认为空且不好识别，我就针对这种情况对它进行重写了一次，这一次，辨识度绝对高/dogedoge/手臂\n"
                         "---------------------\n"
                         "‘分割线’的语法是:\n"
                         "logs.分割线(标题,文本,颜色选择)\n"
@@ -94,7 +108,20 @@ def 帮助():
                         "logs.日志(显示文字,颜色选择)\n"
                         "‘颜色’的语法是:\n"
                         "logs.颜色(输出显示文字,颜色选择)\n"
-                        "---------------------\n"
+                        "‘input输入加强’的语法是：\n"
+                        "logs.输入(输出显示文字,颜色选择)\n\n"
+                        "ps.推荐一个写法（全局参数），语法是\n"
+                        "全局参数='红色'\n"
+                        "a = 输入('a', 全局参数)\n"
+                        "a = 输入('a', 全局参数)\n"
+                        "a = 输入('a', 全局参数)\n"
+                        "全局参数='蓝色'\n"
+                        "a = 输入('a', 全局参数)\n"
+                        "a = 输入('a', 全局参数)\n"
+                        "a = 输入('a', 全局参数)\n"
+                        "这种写法极快的提升了编写的效率，也达到了Fishconsole logs模块的初衷（我们拒绝让一个庞大的工程变得难以调试）"
+
+                        "\n---------------------"
                     )
 
                 if a == "easygui中文辅助模块":
@@ -296,42 +323,42 @@ def 帮助():
                             , "matplotlib中文辅助模块 - 高级教程", "ok")
 
                 if a == "tool玩具模块":
-                    res=window.列表选择对话框("这相当于是我的一个代码仓库吧，我以后写的所有可以拿来用的小程序全都会放在这里（是不是很过分☕😉）", "tool玩具模块", [
+                    res = window.列表选择对话框("这相当于是我的一个代码仓库吧，我以后写的所有可以拿来用的小程序全都会放在这里（是不是很过分☕😉）", "tool玩具模块", [
                         "密码模块",
                         "网易云音乐模块",
                         "排名模块",
                         "文件存在性检测模块"
                     ])
                     for a in res:
-                        if a=="密码模块":
+                        if a == "密码模块":
                             window.弹窗(
-                                      "这个加密其实特别简单，就是把一个字换成另一个字让你看不懂就行了，嗯，他的值是返回过来的\n"
-                                      "本来这个玩具的完全体是有gui的，但是为了顺应模块的需要，我又把它砍了，这就做了一些很无语的调整\n"
-                                      "嗯，就这样把\n"
-                                      "------------------------\n"
-                                      "加密示例：\n"
-                                      "tool.密码(模式，内容，密码)\n\n"
-                                      "解密示例：\n"
-                                      "tool.密码(模式，密码，内容)\n\n"
-                                      ,"password加密模块","ok")
-                        if a=="网易云音乐模块":
+                                "这个加密其实特别简单，就是把一个字换成另一个字让你看不懂就行了，嗯，他的值是返回过来的\n"
+                                "本来这个玩具的完全体是有gui的，但是为了顺应模块的需要，我又把它砍了，这就做了一些很无语的调整\n"
+                                "嗯，就这样把\n"
+                                "------------------------\n"
+                                "加密示例：\n"
+                                "tool.密码(模式，内容，密码)\n\n"
+                                "解密示例：\n"
+                                "tool.密码(模式，密码，内容)\n\n"
+                                , "password加密模块", "ok")
+                        if a == "网易云音乐模块":
                             window.弹窗(
                                 "这个模块其实就是一个爬虫，爬的网易云的歌单里面的歌，最多只能爬一首歌单的前10首，vip的只能爬前几秒，下就下在根目录（我在搞事情哈哈）\n"
                                 "-----------------------------\n\n"
                                 "示例语法\n"
                                 "tool.网易云音乐(['歌单链接1'，'歌单链接2'])"
-                            ,"网易云音乐模块","ok")
-                        if a=="排名模块":
+                                , "网易云音乐模块", "ok")
+                        if a == "排名模块":
                             window.弹窗(
                                 "这个东西呢，就是对你输入的数据排个序，然后再按照你指定的那个序号来返回\n"
                                 "-----------------------------\n\n"
                                 "语法就是\n"
                                 "tool.排名(数据源,第几个)"
-                            ,"排名模块","ok")
-                        if a=="文件存在性检测模块":
+                                , "排名模块", "ok")
+                        if a == "文件存在性检测模块":
                             window.弹窗(
                                 "就是找文件，他返回的是布尔值，有呢就是True，没有就是False，虽然没什么鸟用，但是总有人要用/dogedoge/咖啡\n"
                                 "-----------------------------\n\n"
                                 "语法就是\n"
                                 "tool.文件存在性检测(文件名)"
-                            ,"文件存在性检测模块","ok")
+                                , "文件存在性检测模块", "ok")
